window.Gleam.initSearch([{"doc":"js_parser","title":"js_parser","content":"# js_parser\n\n[![Package Version](https://img.shields.io/hexpm/v/js_parser)](https://hex.pm/packages/js_parser) [![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/js_parser/)\n\nA lexer and parser for JavaScript, written in Gleam.\n\nThis project is inspired by the [`js-tokens`](https://github.com/lydell/js-tokens)\nand [glexer](https://github.com/DanielleMaywood/glexer) packages, and aims to provide\na tool to build ECMA-262 syntax trees for gleam projects.\n\n## Installation\n\n```sh\ngleam add js_parser\n```\n\n## Usage\n\n`someFile.js`\n\n```javascript\nexport function someFunction() {\n    let someVar;\n}\n```\n\nThe lexer can take any string and returns a list of tokens, including whitespace\ncharacters.\n\n```gleam\nimport js_parser\n\npub fn main() {\n  let contents = js_parser.read_file(&quot;path/to/someFile.js&quot;)\n  |&gt; js_parser.parse\n  |&gt; io.debug\n}\n```\n\nShould output:\n\n```plaintext\n[KeywordExport, CharWhitespace(&quot; &quot;), KeywordFunction, CharWhitespace(&quot; &quot;), IdentifierName(&quot;someFunction&quot;), CharOpenParen, CharCloseParen, CharWhitespace(&quot; &quot;), CharOpenBrace, LineTerminatorSequence(&quot;\\n&quot;), CharWhitespace(&quot;    &quot;), IdentifierName(&quot;let&quot;), CharWhitespace(&quot; &quot;), IdentifierName(&quot;someVar&quot;), CharSemicolon, LineTerminatorSequence(&quot;\\n&quot;), CharCloseBrace, LineTerminatorSequence(&quot;\\n&quot;)]\n```\n\n```sh\ngleam run -- --f samples/js/index.js\ngleam test\n```\n","url":"index.html"},{"doc":"js_parser","title":"main","content":"pub fn main() -&gt; String\n A cli with a flag, f, that takes a path to a file and returns its string\n contents.\nSynonyms:\njs_parser.main\njs_parser main","url":"js_parser.html#main"},{"doc":"js_parser","title":"read_file","content":"pub fn read_file(path: String) -&gt; String\n Reads a file and returns either the contents of the file or an empty string\n if it&#39;s not found\nSynonyms:\njs_parser.read_file\njs_parser read_file","url":"js_parser.html#read_file"},{"doc":"js_parser","title":"js_parser","content":"","url":"js_parser.html"},{"doc":"js_parser/predicates","title":"is_end_of_input","content":"pub fn is_end_of_input(char: String) -&gt; Bool\n\nSynonyms:\njs_parser/predicates.is_end_of_input\njs_parser/predicates is_end_of_input","url":"js_parser/predicates.html#is_end_of_input"},{"doc":"js_parser/predicates","title":"is_identifier_start","content":"pub fn is_identifier_start(char: String) -&gt; Bool\n\nSynonyms:\njs_parser/predicates.is_identifier_start\njs_parser/predicates is_identifier_start","url":"js_parser/predicates.html#is_identifier_start"},{"doc":"js_parser/predicates","title":"is_letter","content":"pub fn is_letter(char: String) -&gt; Bool\n\nSynonyms:\njs_parser/predicates.is_letter\njs_parser/predicates is_letter","url":"js_parser/predicates.html#is_letter"},{"doc":"js_parser/predicates","title":"is_punctuator_start","content":"pub fn is_punctuator_start(char: String) -&gt; Bool\n\nSynonyms:\njs_parser/predicates.is_punctuator_start\njs_parser/predicates is_punctuator_start","url":"js_parser/predicates.html#is_punctuator_start"},{"doc":"js_parser/predicates","title":"js_parser/predicates","content":"","url":"js_parser/predicates.html"},{"doc":"js_parser/lexer","title":"Character","content":"pub type Character {\n  CharHashbang\n  CharBacktick\n  CharSingleQuote\n  CharDoubleQuote\n  CharForwardSlash\n  CharBackslash\n  CharAsterisk\n  CharMinus\n  CharPlus\n  CharDot\n  CharEquals\n}\n\nCharHashbang\n\n\nCharBacktick\n\n\nCharSingleQuote\n\n\nCharDoubleQuote\n\n\nCharForwardSlash\n\n\nCharBackslash\n\n\nCharAsterisk\n\n\nCharMinus\n\n\nCharPlus\n\n\nCharDot\n\n\nCharEquals\n\n\nSynonyms:\njs_parser/lexer.Character\njs_parser/lexer Character","url":"js_parser/lexer.html#Character"},{"doc":"js_parser/lexer","title":"ParserState","content":"pub type ParserState {\n  ParserState(input: String, offset: Int, tokens: List(Token))\n}\n\nParserState(input: String, offset: Int, tokens: List(Token))\n\n\nSynonyms:\njs_parser/lexer.ParserState\njs_parser/lexer ParserState","url":"js_parser/lexer.html#ParserState"},{"doc":"js_parser/lexer","title":"Token","content":"pub type Token {\n  StringLiteral(value: String, closed: Bool)\n  NoSubstitutionTemplate(value: String, closed: Bool)\n  TemplateHead(value: String)\n  TemplateMiddle(value: String)\n  TemplateTail(value: String, closed: Bool)\n  RegularExpressionLiteral(value: String, closed: Bool)\n  SingleLineComment(value: String)\n  MultiLineComment(value: String, closed: Bool)\n  HashbangComment(value: String)\n  IdentifierName(value: String)\n  PrivateIdentifier(value: String)\n  NumericLiteral(value: String)\n  Punctuator(value: String)\n  WhiteSpace(value: String)\n  LineTerminatorSequence(value: String)\n  Invalid\n  EOF\n  KeywordAwait\n  KeywordBreak\n  KeywordCase\n  KeywordCatch\n  KeywordClass\n  KeywordConst\n  KeywordContinue\n  KeywordDebugger\n  KeywordDefault\n  KeywordDelete\n  KeywordDo\n  KeywordElse\n  KeywordEnum\n  KeywordExport\n  KeywordExtends\n  KeywordFalse\n  KeywordFinally\n  KeywordFor\n  KeywordFunction\n  KeywordIf\n  KeywordImport\n  KeywordIn\n  KeywordInstanceof\n  KeywordNew\n  KeywordNull\n  KeywordReturn\n  KeywordSuper\n  KeywordSwitch\n  KeywordThis\n  KeywordThrow\n  KeywordTrue\n  KeywordTry\n  KeywordTypeof\n  KeywordVar\n  KeywordVoid\n  KeywordWhile\n  KeywordWith\n  KeywordYield\n  CharSemicolon\n  CharColon\n  CharComma\n  CharOpenBracket\n  CharCloseBracket\n  CharOpenBrace\n  CharCloseBrace\n  CharOpenParen\n  CharCloseParen\n  CharWhitespace(value: String)\n}\n\nStringLiteral(value: String, closed: Bool)\n\n\nNoSubstitutionTemplate(value: String, closed: Bool)\n\n\nTemplateHead(value: String)\n\n\nTemplateMiddle(value: String)\n\n\nTemplateTail(value: String, closed: Bool)\n\n\nRegularExpressionLiteral(value: String, closed: Bool)\n\n\nSingleLineComment(value: String)\n\n\nMultiLineComment(value: String, closed: Bool)\n\n\nHashbangComment(value: String)\n\n\nIdentifierName(value: String)\n\n\nPrivateIdentifier(value: String)\n\n\nNumericLiteral(value: String)\n\n\nPunctuator(value: String)\n\n\nWhiteSpace(value: String)\n\n\nLineTerminatorSequence(value: String)\n\n\nInvalid\n\n\nEOF\n\n\nKeywordAwait\n\n\nKeywordBreak\n\n\nKeywordCase\n\n\nKeywordCatch\n\n\nKeywordClass\n\n\nKeywordConst\n\n\nKeywordContinue\n\n\nKeywordDebugger\n\n\nKeywordDefault\n\n\nKeywordDelete\n\n\nKeywordDo\n\n\nKeywordElse\n\n\nKeywordEnum\n\n\nKeywordExport\n\n\nKeywordExtends\n\n\nKeywordFalse\n\n\nKeywordFinally\n\n\nKeywordFor\n\n\nKeywordFunction\n\n\nKeywordIf\n\n\nKeywordImport\n\n\nKeywordIn\n\n\nKeywordInstanceof\n\n\nKeywordNew\n\n\nKeywordNull\n\n\nKeywordReturn\n\n\nKeywordSuper\n\n\nKeywordSwitch\n\n\nKeywordThis\n\n\nKeywordThrow\n\n\nKeywordTrue\n\n\nKeywordTry\n\n\nKeywordTypeof\n\n\nKeywordVar\n\n\nKeywordVoid\n\n\nKeywordWhile\n\n\nKeywordWith\n\n\nKeywordYield\n\n\nCharSemicolon\n\n\nCharColon\n\n\nCharComma\n\n\nCharOpenBracket\n\n\nCharCloseBracket\n\n\nCharOpenBrace\n\n\nCharCloseBrace\n\n\nCharOpenParen\n\n\nCharCloseParen\n\n\nCharWhitespace(value: String)\n\n\nSynonyms:\njs_parser/lexer.Token\njs_parser/lexer Token","url":"js_parser/lexer.html#Token"},{"doc":"js_parser/lexer","title":"new_parser_state","content":"pub fn new_parser_state(input: String) -&gt; ParserState\n\nSynonyms:\njs_parser/lexer.new_parser_state\njs_parser/lexer new_parser_state","url":"js_parser/lexer.html#new_parser_state"},{"doc":"js_parser/lexer","title":"parse","content":"pub fn parse(input: String) -&gt; List(Token)\n\nSynonyms:\njs_parser/lexer.parse\njs_parser/lexer parse","url":"js_parser/lexer.html#parse"},{"doc":"js_parser/lexer","title":"parse_tokens","content":"pub fn parse_tokens(state: ParserState) -&gt; List(Token)\n\nSynonyms:\njs_parser/lexer.parse_tokens\njs_parser/lexer parse_tokens","url":"js_parser/lexer.html#parse_tokens"},{"doc":"js_parser/lexer","title":"js_parser/lexer","content":"","url":"js_parser/lexer.html"}]);